==> beast-privilege-api-RD1007021-20240304.032737-5-sources.jar: com/thebeastshop/privilege/vo/FrontLimitProductVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;

public class FrontLimitProductVO implements Serializable {
    private Integer id; //规则ID

    private Integer prodId; //商品ID

    private String prodCode; //商品编码

    private String memberCode; //会员编码

    private Integer userLimitNum; //商品用户总限量

    private Integer totalLimitNum; //商品总限量

    private Integer currentBuyNum; //商品已占用数量

    private Integer userBuyNum; //用户已占用数量

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public Integer getUserBuyNum() {
        return userBuyNum;
    }

    public void setUserBuyNum(Integer userBuyNum) {
        this.userBuyNum = userBuyNum;
    }
}

==> beast-privilege-api-RD1007021-20240311.072112-11-sources.jar: com/thebeastshop/privilege/vo/FrontLimitProductVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;

public class FrontLimitProductVO implements Serializable {
    private Integer id; //规则ID

    private Integer prodId; //商品ID

    private String prodCode; //商品编码

    private String memberCode; //会员编码

    private Integer totalLimitNum; //商品总限量
    private Integer currentBuyNum; //商品已占用数量
    private Integer remainLimitNum; //商品剩余数量
    private Integer userLimitNum; //商品用户总限量
    private Integer userBuyNum; //用户已占用数量
    private Integer userRemainNum; //用户剩余数量


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public Integer getUserBuyNum() {
        return userBuyNum;
    }

    public void setUserBuyNum(Integer userBuyNum) {
        this.userBuyNum = userBuyNum;
    }

    public Integer getRemainLimitNum() {
        return remainLimitNum;
    }

    public void setRemainLimitNum(Integer remainLimitNum) {
        this.remainLimitNum = remainLimitNum;
    }

    public Integer getUserRemainNum() {
        return userRemainNum;
    }

    public void setUserRemainNum(Integer userRemainNum) {
        this.userRemainNum = userRemainNum;
    }
}
